@@ -772,7 +772,7 @@ S_openn_cleanup(pTHX_ GV *gv, IO *io, PerlIO *fp, char *mode, const char *oname,
 	fd = PerlIO_fileno(fp);
     }
 #if defined(HAS_FCNTL) && defined(F_SETFD) && defined(FD_CLOEXEC)
-    if (fd > PL_maxsysfd && fcntl(fd, F_SETFD, FD_CLOEXEC) < 0) {
+    if (fd >= 0 && fd > PL_maxsysfd && fcntl(fd, F_SETFD, FD_CLOEXEC) < 0) {
         PerlLIO_close(fd);
         goto say_false;
     }
@@ -1824,8 +1824,18 @@ Perl_apply(pTHX_ I32 type, SV **mark, SV **sp)
                         int fd = PerlIO_fileno(IoIFP(GvIOn(gv)));
 			APPLY_TAINT_PROPER();
                         if (fd < 0) {
-                            SETERRNO(EBADF,RMS_IFI);
+			    SETERRNO(EBADF,RMS_IFI);
 			    tot--;
+#if Uid_t_sign == 1
+			} else if (val < 0) {
+			    SETERRNO(EINVAL,LIB_INVARG);
+			    tot--;
+#endif
+#if Gid_t_sign == 1
+			} else if (val2 < 0) {
+			    SETERRNO(EINVAL,LIB_INVARG);
+			    tot--;
+#endif
                         } else if (fchown(fd, val, val2))
 			    tot--;
 #else
